cachefx

package module
v0.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 14, 2025 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	ErrInvalidFactoryConfig = errors.New("invalid config")
)

Functions

func Module

func Module() fx.Option

Types

type Config

type Config struct {
	URL string
}

Config controls the cache backend via a URL (e.g., "memory://", "redis://...").

type Factory

type Factory interface {
	New(name string) (cache.Cache, error)
	WithName(name string) Factory
}

func NewFactory

func NewFactory(config Config) (Factory, error)

Directories

Path Synopsis
Package cache provides a flexible caching abstraction with multiple backend implementations.
Package cache provides a flexible caching abstraction with multiple backend implementations.

Jump to